@@ -1,12 +1,9 @@
 import csv
 from abc import abstractmethod, ABC
-from io import BytesIO, StringIO
+from io import StringIO
 from json import JSONDecoder, JSONDecodeError
-from numbers import Number
 from typing import Generic, TypeVar, Union, Dict, Type, Iterator, Sequence, List
 
-import pandas as pd
-
 R = TypeVar('R')
 
 
@@ -35,45 +32,6 @@ class Reader(ABC, Generic[R]):
         return NotImplemented
 
 
-class Pandas(Reader[pd.DataFrame]):
-    def __init__(self, strict: bool = False):
-        self._strict = strict
-
-    def read(self, bs: Union[bytes, bytearray], columns: Dict[str, Type]) -> pd.DataFrame:
-        if self._strict:
-            return pd.read_csv(BytesIO(bs), header=None, names=columns.keys(), dtype=columns)
-        else:
-            df = pd.read_csv(BytesIO(bs), header=None, names=columns.keys())
-            for c, t in columns.items():
-                if issubclass(t, Number):
-                    df[c] = pd.to_numeric(df[c], errors='coerce')
-            return df
-
-    def combine(self, results: Sequence[pd.DataFrame]) -> pd.DataFrame:
-        if not results:
-            return pd.DataFrame([])
-        return pd.concat(results)
-
-    @property
-    def supports_caching(self):
-        return True
-
-    @property
-    def serialization(self):
-        return {'CSV': {
-            'QuoteFields': 'ALWAYS',
-            'QuoteEscapeCharacter': '"',
-            'FieldDelimiter': ',',
-            'QuoteCharacter': '"',
-        }}
-
-    def read_cache(self, cache_file: str) -> pd.DataFrame:
-        return pd.read_parquet(cache_file)
-
-    def write_cache(self, cache_file: str, contents: pd.DataFrame):
-        contents.to_parquet(cache_file)
-
-
 RowDict = Sequence[Union[int, float, str]]
 
 
